{% block docs_sidebar %}
{% if sidebars %}
<!-- Only show if we have sidebars configured, else just a small margin  -->
<div class="bd-sidebar-primary col-12 col-md-2 bd-sidebar">
  <div class="sidebar-start-items">
    {%- for sidebartemplate in sidebars %}
    {%- include sidebartemplate %}
    {%- endfor %}
  </div>
  <div class="sidebar-end-items">
    {%- for leftsidebartemplate in theme_left_sidebar_end %}
    {%- include leftsidebartemplate %}
    {%- endfor %}
  </div>
</div>
{% else %}
<div class="sidebar-primary col-12 col-md-1 col-xl-2 bd-sidebar no-sidebar"></div>
{% endif %}
{% endblock %}
