:root[data-theme="light"] {
    --pst-color-primary: rgb(47, 47, 47);
    --pst-color-link: rgb(0, 170, 65);
}

.nav-link {
    white-space: nowrap;
}

.showcase-table {
    border-spacing: 15px
}

.showcase-table td {
    border: 0px;
    vertical-align: top;
}

.pl-md-5, .px-md-5 {
    padding-left: 1rem !important;
}

.pt-md-5, .py-md-5 {
    padding-top: 1rem !important;
}

.cell_output {
    padding-left: 0;
}

@media (min-width: 1200px) {
    .container, .container-lg, .container-md, .container-sm, .container-xl {
	max-width: 1600px;
    }
}

#scroller-right {
    max-width: 14%;
}

@media (max-width: 1400px) {
    #scroller-right {
	position: relative;
	right: unset;
	top: unset;
	max-width: 100%;
	transform: unset;
    }
}

#navbar-icon-links i.fa-github-square:before {
    color: white;
}

.fa-discourse:before {
    color: white;
}

button.toggle-button {
    display: none;
}

.toggle-hidden:not(.admonition) {
    height: 0;
}

.tag_hide-input {
    margin-bottom: 0 !important;
}

details.hide.above-input {
    display: none;
}

.toggle-hidden + .cell_output {
    margin-top: 0 !important;
}

dl.field-list {
    display: none
}

/* Improve styling */

div.cell div.cell_input {
    border: none;
}

.highlight {
    border-radius: 4px;
}

html[data-theme="light"] .highlight {
    background-color: #263238;
    color: #f8f8f2;
}

pre[id^='codecell'] {
    background-color: unset;
    border: none;
    border-radius: 0.5em;
    color: #f8f8f2;
    box-shadow: none;
    padding: 1.5em;
}

button.copybtn {
    background-color: #263238;
}

button.copybtn:hover {
    background-color: #263238;
    color: #f8f8f2;
}

.highlight button.copybtn:hover {
    background: none
}

.o-tooltip--left:after {
    background: none;
}

ul.current.nav.bd-sidenav {
    padding: 0;
}
